@@ -642,7 +642,7 @@ main(int argc, char* argv[]) try {
 
   if (required_cppflags) {
     if (required_application) {
-      std::string cppflags = "-I/usr/lib/swipl/include ";
+      std::string cppflags = "-I/usr/lib/swipl/include";
       std::string s = "${prefix}/include";
       replace_prefixes(s);
       // `/usr/include' is the standard include directory:
@@ -654,9 +654,9 @@ main(int argc, char* argv[]) try {
         // Avoid duplicating the -I options.
         if (cppflags.find(s) != std::string::npos)
           s = "";
-        if (s.length() > 0 && strlen("-I/usr/lib/swipl/include ") > 0)
+        if (s.length() > 0 && strlen("-I/usr/lib/swipl/include") > 0)
           s += ' ';
-        s += "-I/usr/lib/swipl/include ";
+        s += "-I/usr/lib/swipl/include";
       }
       if (s.length() > 0 && strlen("") > 0)
           s += ' ';
@@ -664,19 +664,19 @@ main(int argc, char* argv[]) try {
       portray("CPPFLAGS", s);
     }
     else
-      portray("CPPFLAGS", "-I/usr/lib/swipl/include ");
+      portray("CPPFLAGS", "-I/usr/lib/swipl/include");
   }
 
   if (required_cflags)
-    portray("CFLAGS", " -g -O2 -frounding-math -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/ppl/src=/usr/src/debug/ppl -flto=auto -W -Wall");
+    portray("CFLAGS", " -g -O2 -frounding-math -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/ppl/src=/usr/src/debug/ppl -flto=auto -W -Wall");
 
   if (required_cxxflags)
-    portray("CXXFLAGS", " -g -O2 -frounding-math -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -Wp,-D_GLIBCXX_ASSERTIONS -g -ffile-prefix-map=/build/ppl/src=/usr/src/debug/ppl -flto=auto -W -Wall");
+    portray("CXXFLAGS", " -g -O2 -frounding-math -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -g -ffile-prefix-map=/build/ppl/src=/usr/src/debug/ppl -flto=auto -W -Wall");
 
   if (required_ldflags) {
     std::string s = "${exec_prefix}/lib";
     replace_prefixes(s);
-    const std::string ldflags = "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto";
+    const std::string ldflags = "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto";
     // `/usr/lib' is the standard library directory:
     // thus it needs not be specified.
     if (s == "/usr/lib")
